summaryrefslogtreecommitdiffstats
path: root/src/dbusInterface.cpp
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2013-05-05 14:38:12 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2013-05-05 14:38:12 -0500
commita14f98704b2cfaacbb4114214d4fa1305a28cb64 (patch)
tree3389dbb8dce67157d1929ee6ca51518484d01f18 /src/dbusInterface.cpp
parent70932ba22c922847b66fb256b28b870d62697511 (diff)
downloadtdepowersave-a14f98704b2cfaacbb4114214d4fa1305a28cb64.tar.gz
tdepowersave-a14f98704b2cfaacbb4114214d4fa1305a28cb64.zip
Fix typos.
Diffstat (limited to 'src/dbusInterface.cpp')
-rw-r--r--src/dbusInterface.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/dbusInterface.cpp b/src/dbusInterface.cpp
index 3f75084..82cffd6 100644
--- a/src/dbusInterface.cpp
+++ b/src/dbusInterface.cpp
@@ -42,7 +42,7 @@ dbusInterface::dbusInterface(){
kdDebugFuncIn(trace);
dbus_is_connected = false;
- aquiredPolicyPower = false;
+ acquiredPolicyPower = false;
// add pointer to this for filter_function()
myInstance=this;
@@ -79,11 +79,11 @@ bool dbusInterface::isConnectedToDBUS() {
* This function return information if the org.freedesktop.Policy.Power
* interface was claimed.
* \return boolean with the status of claim the interface
* \retval true if aquired
* \retval false if not
*/
-bool dbusInterface::aquiredPolicyPowerInterface() {
- return aquiredPolicyPower;
+bool dbusInterface::acquiredPolicyPowerInterface() {
+ return acquiredPolicyPower;
}
/*!
@@ -145,7 +145,7 @@ bool dbusInterface::initDBUS(){
return false;
}
- aquirePolicyPowerIface();
+ acquirePolicyPowerIface();
dbus_connection_set_exit_on_disconnect( dbus_connection, false );
@@ -175,12 +175,12 @@ bool dbusInterface::initDBUS(){
}
/*!
* This function aquire the org.freedesktop.Policy.Power interface
* \return boolean with the result of the operation
* \retval true if successful aquired the interface
* \retval false if unsuccessful
*/
-bool dbusInterface::aquirePolicyPowerIface(){
+bool dbusInterface::acquirePolicyPowerIface(){
kdDebugFuncIn(trace);
if (dbus_connection == NULL) {
@@ -192,26 +192,26 @@ bool dbusInterface::aquirePolicyPowerIface(){
DBUS_NAME_FLAG_REPLACE_EXISTING, NULL)) {
case DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER:
kdDebug() << "Acquired org.freedesktop.Policy.Power interface" << endl;
- aquiredPolicyPower = true;
+ acquiredPolicyPower = true;
break;
case DBUS_REQUEST_NAME_REPLY_IN_QUEUE:
- kdWarning() << "Queued to aquire org.freedesktop.Policy.Power interface" << endl;
- aquiredPolicyPower = false;
+ kdWarning() << "Queued to acquire org.freedesktop.Policy.Power interface" << endl;
+ acquiredPolicyPower = false;
break;
default:
- kdWarning() << "Unknown error while aquire org.freedesktop.Policy.Power interface" << endl;
- aquiredPolicyPower = false;
+ kdWarning() << "Unknown error while acquire org.freedesktop.Policy.Power interface" << endl;
+ acquiredPolicyPower = false;
break;
}
kdDebugFuncOut(trace);
- return aquiredPolicyPower;
+ return acquiredPolicyPower;
}
/*!
* This function release the org.freedesktop.Policy.Power interface
* \return boolean with the result of the operation
* \retval true if successful aquired the interface
* \retval false if unsuccessful
*/
bool dbusInterface::releasePolicyPowerIface(){
@@ -238,7 +238,7 @@ bool dbusInterface::releasePolicyPowerIface(){
case DBUS_RELEASE_NAME_REPLY_RELEASED:
kdDebug() << "Released org.freedesktop.Policy.Power interface" << endl;
retval = true;
- aquiredPolicyPower = false;
+ acquiredPolicyPower = false;
break;
case DBUS_RELEASE_NAME_REPLY_NOT_OWNER:
kdWarning() << "Couldn't release org.freedesktop.Policy.Power, not the owner" << endl;
@@ -502,9 +502,9 @@ void dbusInterface::emitMsgReceived( msg_type type, TQString message, TQString s
if (type == POLICY_POWER_OWNER_CHANGED) {
if (message.startsWith("NOW_OWNER"))
- aquiredPolicyPower = true;
+ acquiredPolicyPower = true;
else
- aquiredPolicyPower = false;
+ acquiredPolicyPower = false;
}
emit msgReceived_withStringString( type, message, string );
@@ -79,11 +79,11 @@ bool dbusInterface::isConnectedToDBUS() {
* interface was claimed.
* \return boolean with the status of claim the interface
- * \retval true if aquired
+ * \retval true if acquired
* \retval false if not
*/
@@ -175,12 +175,12 @@ bool dbusInterface::initDBUS(){
}
/*!
- * This function aquire the org.freedesktop.Policy.Power interface
+ * This function acquire the org.freedesktop.Policy.Power interface
* \return boolean with the result of the operation
@@ -175,12 +175,12 @@ bool dbusInterface::initDBUS(){
* \return boolean with the result of the operation
- * \retval true if successful aquired the interface
+ * \retval true if successful acquired the interface
* \retval false if unsuccessful
*/
@@ -192,26 +192,26 @@ bool dbusInterface::aquirePolicyPowerIface(){
* This function release the org.freedesktop.Policy.Power interface
* \return boolean with the result of the operation
- * \retval true if successful aquired the interface
+ * \retval true if successful acquired the interface
* \retval false if unsuccessful
*/